Learn R Programming

SPARSEMODr (version 1.2.0)

SPARSEMODr-package: SPAtial Resolution-SEnsitive Models of Outbreak Dynamics

Description

Implementation of spatially-explicit, stochastic disease models with customizable time windows that describe how parameter values fluctuate over the course of the simulation (e.g., in response to public health or conservation interventions).

Arguments

Author

Maintainer: Joseph Mihaljevic <joseph.mihaljevic@nau.edu>

Details

Stochastic realizations of the models can be performed in parallel using the model_parallel functions, and time-varying parameters can be supplied using time_windows objects.